import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.CostofLivingIndex)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.CostofLivingIndex))
  	.on("mouseover", d => console.log(d.data.CostofLivingIndex));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.CostofLivingIndex));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.CostofLivingIndex));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/Nikitha123171/30a441d0c19d1a2a28a0a3f90f145a7e/raw/c69b0f974098f6b85d5b7a71fe006f8c322e71f4/ICE%25206%2520dataset%2520CSV.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.CostofLivingIndex-data1.CostofLivingIndex);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});